@@ -4,7 +4,6 @@ from configurations import Configuration, values
 
 
 class BaseConfig(Configuration):
-    BASE_DIR = Path(__file__).resolve(strict=True).parent.parent
     DEBUG = values.BooleanValue(False)
     ALLOWED_HOSTS = values.ListValue()
     SECRET_KEY = values.SecretValue()
@@ -44,10 +43,7 @@ class BaseConfig(Configuration):
     ]
 
     PROJECT_APPS = [
-        'usermodel',
-        'ses_sns',
-        'theme',
-        'demo',
+
     ]
 
     @property
